@@ -85,7 +85,7 @@ class faciletoolkit:
             
     @staticmethod
     @keyword
-    def open_browser(url, browser):
+    def open_browser(url, browser, width=None, height=None):
         """ Opens the given browser and goes on url.
             browser may be Firefox or Chrome. Firefox may be passed as "ff" aswell.
         """
@@ -102,7 +102,10 @@ class faciletoolkit:
             chrome_options.add_argument("--disable-dev-shm-usage")
             chrome_options.add_experimental_option("excludeSwitches", ["enable-automation"])
             chrome_options.set_capability("pageLoadStrategy", "eager")
+            if None not in (width, height):
+                chrome_options.add_argument("--window-size={},{}".format(width, height))
             session.open_browser(url, browser, options=chrome_options)
+        
         elif browser == "firefox" or "ff":
             firefox_options = webdriver.FirefoxOptions()
             firefox_options.add_argument("--no-sandbox")
@@ -110,6 +113,9 @@ class faciletoolkit:
             firefox_options.add_argument("--disable-extensions")
             firefox_options.add_argument("--ignore-certificate-errors")
             firefox_options.set_capability("pageLoadStrategy", "eager")
+            if None not in (width, height):
+                firefox_options.add_argument("--width={}".format(width))
+                firefox_options.add_argument("--height={}".format(height))
             session.open_browser(url, browser, options=firefox_options)
         else:
             raise RobotError("unexpected")
